%global debug_package %{nil}
%define __python %{__python3}

# Dont provide or require internal libs. Using new rpm builtin filtering
%global _privatelibs libjack[.]so.*
%global __provides_exclude ^(%{_privatelibs})$
%global __requires_exclude ^(%{_privatelibs})$

# External Carla-Plugins
%define plugins_commit 7e6c2206f0e2ba65a996e67e98c005af1412684c

Name:           carla
Version:        2.5.8
Release:        %mkrel 1
Summary:        An audio plugin host
License:        GPLv2+
Group:          Sound/Utilities
Url:            https://kxstudio.linuxaudio.org/Applications:Carla

Source0:        https://github.com/falkTX/Carla/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/falkTX/Carla-Plugins/archive/%{plugins_commit}.tar.gz
Patch0:         0001-Use-system-flac-vorbis-ogg.patch
Patch1:         0002-Remove-rpath-from-.pc-files.patch
Patch2:         0003-Use-correct-plugin-paths-for-openSUSE.patch
Patch3:         Carla-single-libs-path.patch

BuildRequires:  file
BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(pkg-config)

# for extra native plugins
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gig)
BuildRequires:  pkgconfig(libprojectM)
BuildRequires:  pkgconfig(ntk)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(pyliblo)
BuildRequires:  python3dist(rdflib)
BuildRequires:  python3-qt5-devel
# for extra samplers support
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(gl)
# for plugin GUIs
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(mxml)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)

Requires:       python3-pyliblo
Requires:       python3-rdflib
Requires:       python3-qt5

%description
Carla is an audio plugin host, with support for many audio drivers
and plugin formats. It features automation of parameters via MIDI CC
and full OSC control. It currently supports LADSPA, DSSI, LV2, VST2/3
and AU plugin formats, plus GIG, SF2 and SFZ sounds banks.
It further supports bridging Window plugins using Wine.

%files
%doc README.md doc
%{_bindir}/carla
%{_bindir}/carla-control
%{_bindir}/carla-database
%{_bindir}/carla-jack-multi
%{_bindir}/carla-jack-patchbayplugin
%{_bindir}/carla-jack-single
%{_bindir}/carla-osc-gui
%{_bindir}/carla-patchbay
%{_bindir}/carla-rack
%{_bindir}/carla-settings
%{_bindir}/carla-single
%{_libdir}/carla/
%{_libdir}/lv2/carla.lv2/
%{_datadir}/carla/
%{_datadir}/applications/carla.desktop
%{_datadir}/applications/carla-control.desktop
%{_datadir}/applications/carla-jack-multi.desktop
%{_datadir}/applications/carla-jack-single.desktop
%{_datadir}/applications/carla-patchbay.desktop
%{_datadir}/applications/carla-rack.desktop
%{_datadir}/icons/hicolor/*/apps/carla*.*
%{_datadir}/mime/packages/carla.xml
%{_metainfodir}/studio.kx.carla.appdata.xml

#--------------------------------------------------------------------

%package devel
Summary:        Header files to access Carla's API
Group:          Development/C++
Requires:       carla = %{version}-%{release}

%description devel
This package contains header files needed when writing software using
Carla's several APIs.

%files devel
%{_includedir}/carla/
%{_libdir}/pkgconfig/carla-host-plugin.pc
%{_libdir}/pkgconfig/carla-native-plugin.pc
%{_libdir}/pkgconfig/carla-standalone.pc
%{_libdir}/pkgconfig/carla-utils.pc

#--------------------------------------------------------------------

%package vst
Summary:        CarlaRack and CarlaPatchbay VST plugins
Group:          Sound/Utilities
Requires:       carla = %{version}-%{release}

%description vst
This package contains Carla VST plugins, including CarlaPatchbayFX,
CarlaPatchbay, CarlaRackFX, and CarlaRack.

%files vst
%{_libdir}/vst/

#--------------------------------------------------------------------

%prep
%setup -q -n Carla-%{version} -a1
%autopatch -p1

# External Carla-Plugins
mv Carla-Plugins-%{plugins_commit}/* source/native-plugins/external/
rm -r Carla-Plugins-%{plugins_commit}

# remove windows stuff
rm -rf data/{macos,windows}

# E: wrong-script-interpreter /usr/lib64/python3/dist-packages/carla_backend.py /usr/bin/env python3
find . -type f \( -name "*.py" \) -exec sed -i "s|#!/usr/bin/env python3|#!%{__python3}|g" {} \;
sed -i "s|#!/usr/bin/env python3|#!%{__python3}|" source/frontend/{carla,carla-control,carla-jack-multi,carla-jack-single,carla-patchbay,carla-rack}
sed -i "s|#!/usr/bin/env python|#!%{__python3}|" source/frontend/widgets/paramspinbox.py

# fix libdir path
sed -i "s|/lib/carla|/%{_lib}/carla|" \
  data/{carla,carla-control,carla-database,carla-jack-multi,carla-jack-patchbayplugin,carla-jack-single,carla-patchbay,carla-rack,carla-settings} \
  source/backend/engine/CarlaEngineJack.cpp

# Fix metainfo install dir
sed -i -e 's|$(DESTDIR)$(PREFIX)/share/appdata/studio.kx.carla.appdata.xml|$(DESTDIR)$(PREFIX)/share/metainfo/studio.kx.carla.appdata.xml|g' Makefile
sed -i -e 's|$(DESTDIR)$(PREFIX)/share/appdata|$(DESTDIR)$(PREFIX)/share/metainfo|g' Makefile

%build
%set_build_flags
export EXTERNAL_PLUGINS=true
make features
%make_build SKIP_STRIPPING=true NOOPT=true

%install
%make_install  -- PREFIX="%{_prefix}" LIBDIR="%{_libdir}"

# Create a vst directory
install -m 755 -d %{buildroot}/%{_libdir}/vst/

# E: non-executable-script /usr/share/carla/paramspinbox.py 644 /usr/bin/env python
find %{buildroot} -type f \( -name "*.py" \) -exec chmod a+x {} \;

# E: non-executable-script /usr/share/carla/carla 644 /usr/bin/python3
chmod a+x %{buildroot}%{_datadir}/carla/{carla,carla-control,carla-jack-multi,carla-jack-single,carla-patchbay,carla-rack}

# fix perm due rpmlint W: unstripped-binary-or-object /usr/lib64/carla/libcarla_interposer-jack-x11.so
find %{buildroot}%{_libdir} -name '*.so' -exec chmod +x '{}' ';'


%changelog
* Thu Aug 22 2024 daviddavid <daviddavid> 2.5.8-1.mga10
+ Revision: 2087456
- new version: 2.5.8

* Mon Oct 23 2023 daviddavid <daviddavid> 2.5.7-3.mga10
+ Revision: 2000373
- enable sdl2 support

* Mon Oct 23 2023 daviddavid <daviddavid> 2.5.7-2.mga10
+ Revision: 2000372
- enable external carla plugins (mga#32367)

* Sat Sep 30 2023 kekepower <kekepower> 2.5.7-1.mga10
+ Revision: 1992410
- Update to version 2.5.7

* Sun Jun 04 2023 kekepower <kekepower> 2.5.5-1.mga9
+ Revision: 1960888
- Update to version 2.5.5
- Rediff 0002-Remove-rpath-from-.pc-files.patch

* Tue Mar 28 2023 luigiwalser <luigiwalser> 2.5.4-1.mga9
+ Revision: 1950533
- 2.5.4
- rename opensuse patches as they did
- remove upstream patch

* Mon Mar 06 2023 kekepower <kekepower> 2.5.3-3.mga9
+ Revision: 1947908
- Add GitHub PR to fix launch with recent Qt
  o https://github.com/falkTX/Carla/pull/1734

* Sat Feb 04 2023 daviddavid <daviddavid> 2.5.3-2.mga9
+ Revision: 1938025
- drop Qt4 support

* Wed Jan 25 2023 luigiwalser <luigiwalser> 2.5.3-1.mga9
+ Revision: 1936087
- 2.5.3

* Mon Oct 24 2022 luigiwalser <luigiwalser> 2.5.2-1.mga9
+ Revision: 1899018
- 2.5.2
- rediff patches 0 and 1

* Wed Oct 12 2022 luigiwalser <luigiwalser> 2.5.1-1.mga9
+ Revision: 1896627
- 2.5.1
- update patch0 from opensuse
- drop expression-error patch (via fedora)

* Mon Jul 25 2022 luigiwalser <luigiwalser> 2.4.4-1.mga9
+ Revision: 1871576
- 2.4.4

* Mon Apr 25 2022 luigiwalser <luigiwalser> 2.4.3-1.mga9
+ Revision: 1853653
- 2.4.3

* Fri Mar 25 2022 akien <akien> 2.4.2-2.mga9
+ Revision: 1826221
- Also require python3-pyliblo and python3-rdflib
- Require python3-qt5 (mga#30207)
- Require newly packaged pyliblo for carla-config
- Fix libdir path for carla-jack-patchbayplugin

* Wed Mar 02 2022 luigiwalser <luigiwalser> 2.4.2-1.mga9
+ Revision: 1787917
- 2.4.2
- update patch 1 from openSUSE
- add two patches from Fedora

* Mon Oct 25 2021 luigiwalser <luigiwalser> 2.4.1-1.mga9
+ Revision: 1752898
- 2.4.1
- update patch 0 from opensuse

* Sun Aug 08 2021 luigiwalser <luigiwalser> 2.3.2-1.mga9
+ Revision: 1740713
- 2.3.2

* Sun Aug 08 2021 luigiwalser <luigiwalser> 2.3.1-1.mga9
+ Revision: 1740615
- 2.3.1
- sync patches with opensuse
- sync appdata file and spec changes with fedora
- rebuild for fluidsynth

* Wed Dec 16 2020 umeabot <umeabot> 1.9.14-0.git20190227.5.mga8
+ Revision: 1658187
- Rebuild for new Qt5

* Wed Jul 29 2020 daviddavid <daviddavid> 1.9.14-0.git20190227.4.mga8
+ Revision: 1609506
- add upstream patch to fix build with Qt 5.15

* Tue Apr 28 2020 daviddavid <daviddavid> 1.9.14-0.git20190227.3.mga8
+ Revision: 1572611
- rebuild for new libprojectm 3.1.3

* Sat Feb 15 2020 umeabot <umeabot> 1.9.14-0.git20190227.2.mga8
+ Revision: 1524664
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sat Mar 30 2019 luigiwalser <luigiwalser> 1.9.14-0.git20190227.1.mga7
+ Revision: 1381969
- 1.9.14 snapshot from opensuse (aka 2.0-RC4)

* Sat Mar 30 2019 daviddavid <daviddavid> 1.9.12-0.git20181025.3.mga7
+ Revision: 1381592
- add patch from upstream zynaddsubfx to added compatibility with MXML 3.0
+ umeabot <umeabot>
- Qt5 Rebuild

* Wed Feb 27 2019 daviddavid <daviddavid> 1.9.12-0.git20181025.2.mga7
+ Revision: 1370416
- filter out private libs

* Tue Jan 15 2019 luigiwalser <luigiwalser> 1.9.12-0.git20181025.1.mga7
+ Revision: 1357050
- 1.9.12 snapshot from opensuse (aka 2.0-RC2)
- rediff patches
- add patch from opensuse to build against system flac and vorbis
- no longer builds against linuxsampler
+ daviddavid <daviddavid>
- rebuild for new fluidsynth 2.0.3

* Fri Jan 11 2019 daviddavid <daviddavid> 1.9.7-0.git20170512.10.mga7
+ Revision: 1354842
- rebuild for new Python 3.7

* Sat Sep 22 2018 umeabot <umeabot> 1.9.7-0.git20170512.9.mga7
+ Revision: 1295993
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 wally <wally> 1.9.7-0.git20170512.8.mga7
+ Revision: 1248784
- build without linuxsampler on aarch64

* Fri Jul 06 2018 daviddavid <daviddavid> 1.9.7-0.git20170512.7.mga7
+ Revision: 1242165
- update files list (no more __pycache__ reference)

* Sat Dec 30 2017 wally <wally> 1.9.7-0.git20170512.6.mga7
+ Revision: 1187990
- rebuild for new liblinuxsampler

* Wed Aug 09 2017 pterjan <pterjan> 1.9.7-0.git20170512.5.mga7
+ Revision: 1139143
- Rebuild for python 3.6

* Tue May 30 2017 pterjan <pterjan> 1.9.7-0.git20170512.4.mga6
+ Revision: 1105615
- Do not force sse+sse2 on all architectures

* Fri May 12 2017 animtim <animtim> 1.9.7-0.git20170512.3.mga6
+ Revision: 1100621
- add desktop categories patch
- fix icons path
- add missing BR
- add the patch
- fix spec and add install patch
- imported package carla

